.. @+leo-ver=5-thin
.. @+node:peckj.20130503092808.1683: * @file leo.external.concurrent.futures.rst
.. @@language rest
futures Package
===============

:mod:`futures` Package
----------------------

.. automodule:: leo.external.concurrent.futures
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`_base` Module
-------------------

.. automodule:: leo.external.concurrent.futures._base
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`_compat` Module
---------------------

.. automodule:: leo.external.concurrent.futures._compat
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`process` Module
---------------------

.. automodule:: leo.external.concurrent.futures.process
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`thread` Module
--------------------

.. automodule:: leo.external.concurrent.futures.thread
    :members:
    :undoc-members:
    :show-inheritance:

.. @-leo
